Root class for common functionality of this package
Root class for common functionality of this package
modelthe statistical model
datatraining data
model_fittrained object
formulaObject of class formula or character describing the model fit
termsterms of the formula
endpointTarget variable
dist_matrixA matrix with distances
order_matrixA matrix with the order indices for similar cases search
endPointDeprecated: use endpoint instead.
distMatDeprecated: use dist_matrix instead.
orderMatDeprecated: use order_matrix instead.
new()Initialize object for searching similar cases
CBRBase$new(formula, data)formulaObject of class formula or character describing the model fit
dataTraining data of class data.frame
fit()Fit the Model
CBRBase$fit()
calc_distance_matrix()Calculates the distance matrix
CBRBase$calc_distance_matrix(query = NULL)queryQuery data of class data.frame
get_similar_cases()Extracts similar cases
CBRBase$get_similar_cases(query, k = 1, add_distance = TRUE, merge = FALSE)queryQuery data of class data.frame
knumber of similar cases
add_distanceAdd distance to result data.frame
mergeAdd query data to matched cases data.frame
clone()The objects of this class are cloneable with this method.
CBRBase$clone(deep = FALSE)deepWhether to make a deep clone.